@@ -153,7 +153,7 @@ class Dialcentral(object):
 			self._window,
 			self._widgetTree.get_widget("dialpad_menubar"),
 		)
-		if hildonize.IS_FREMANTLE_SUPPORTED:
+		if not hildonize.GTK_MENU_USED:
 			button = gtk.Button("New Login")
 			button.connect("clicked", self._on_clearcookies_clicked)
 			menu.append(button)
@@ -741,14 +741,17 @@ class Dialcentral(object):
 					self._window.unfullscreen()
 				else:
 					self._window.fullscreen()
-			elif event.keyval == ord("l") and event.get_state() & gtk.gdk.CONTROL_MASK:
+			elif event.keyval == gtk.keysyms.l and event.get_state() & gtk.gdk.CONTROL_MASK:
 				with open(constants._user_logpath_, "r") as f:
 					logLines = f.xreadlines()
 					log = "".join(logLines)
 					self._clipboard.set_text(str(log))
-			elif event.keyval in (ord("w"), ord("q")) and event.get_state() & gtk.gdk.CONTROL_MASK:
+			elif (
+				event.keyval in (gtk.keysyms.w, gtk.keysyms.q) and
+				event.get_state() & gtk.gdk.CONTROL_MASK
+			):
 				self._window.destroy()
-			elif event.keyval == ord("r") and event.get_state() & gtk.gdk.CONTROL_MASK:
+			elif event.keyval == gtk.keysyms.r and event.get_state() & gtk.gdk.CONTROL_MASK:
 				self._refresh_active_tab()
 		except Exception, e:
 			self._errorDisplay.push_exception()
